@@ -1,9 +1,9 @@
 import boto3
 
-def subscribe(protocol, endpoint):
+def subscribe(PROTOCOL, ENDPOINT):
     sns = boto3.client('sns', region_name='us-east-1')
     topic = 'arn:aws:sns:us-east-1:672168469627:Consultant-SNS-Topic'
-    subscription = sns.subscribe(TopicArn=topic, Protocol=protocol, Endpoint=endpoint, ReturnSubscriptionArn=True)
+    subscription = sns.subscribe(TopicArn=topic, Protocol=PROTOCOL, Endpoint=ENDPOINT, ReturnSubscriptionArn=True)
     return subscription
             
 def publish(MESSAGE, SUBJECT):
